@@ -76,13 +76,12 @@ def parse_arguments() -> argparse.Namespace:
     )
 
     parser.add_argument(
-        '--default-version',
+        '--update-version',
         action='store_true',
-        dest='use_default_version',
+        dest='update_version',
         required=False,
-        type=bool,
-        help="indicate whether to use a default version build number for the Unreal "
-             "Engine project if none defined in the configuration file"
+        help="indicate whether to update the defined in the Unreal Engine project. "
+             "This argument MUST be used with the argument `--build-number`."
     )
 
     parser.add_argument(
@@ -112,14 +111,12 @@ def run():
 
     setup_logger(logging_formatter=DEFAULT_LOGGING_FORMATTER, logging_level=arguments.logging_level)
 
-    version = project_version.find_project_version_ini_file(
-        arguments.path,
-        require_semantic_versioning=True,
-        default_version=DEFAULT_VERSION if arguments.use_default_version else None,
-    )
+    version = project_version.find_project_version_ini_file(arguments.path, require_semantic_versioning=True)
 
     if arguments.build_number:
         version = f'{version}+{arguments.build_number}'
+        if arguments.update_version:
+            project_version.update_project_version_ini_file(arguments.path, version)
 
     print(version)
 
