@@ -24,14 +24,15 @@ from majormode.perseus.model.version import Version
 
 DEFAULT_VERSION = Version(0, 0, 1)
 
-REGEX_PATTERN_PROPERTY = r'^ProjectVersion\s*=\s*([a-zA-Z0-9\.\-]+)\s*$'
+UNREAL_ENGINE_CONFIG_PROPERTY_PROJECT_VERSION = 'ProjectVersion'
+
+REGEX_PATTERN_PROPERTY = rf'^{UNREAL_ENGINE_CONFIG_PROPERTY_PROJECT_VERSION}\s*=\s*([a-zA-Z0-9\.\-]+)\s*$'
 REGEX_PROPERTY = re.compile(REGEX_PATTERN_PROPERTY)
 
 
 def find_project_version_ini_file(
         path: Path,
-        require_semantic_versioning: bool = False,
-        default_version: str or Version = None) -> str or Version:
+        require_semantic_versioning: bool = False) -> str or Version:
     """
     Return the project version of an Unreal Engine project.
 
@@ -52,9 +53,6 @@ def find_project_version_ini_file(
         identified in the configuration file of the Unreal Engine project
         MUST comply with Semantic Versioning.
 
-    @param default_version: The default version to return when the Unreal
-        Engine configuration file has no project version defined.
-
 
     @return: The version of the Unreal Engine project.
 
@@ -86,11 +84,50 @@ def find_project_version_ini_file(
 
             return project_version
 
-    if default_version:
-        sys.stderr.write(
-            f"No project version defined in the Unreal Engine's configuration file {config_file_path};"
-            f"using the default version {default_version}{os.linesep}"
-        )
-        return default_version
-
     raise ValueError(f"The Unreal Engine project has no version defined in the configuration file {config_file_path}")
+
+
+def update_project_version_ini_file(
+        path: Path,
+        version: str or Version) -> None:
+    """
+    Update the project version of an Unreal Engine project.
+
+
+    The version of an Unreal Engine project is identified in the attribute
+    `ProjectVersion` of the section
+    `[/Script/EngineSettings.GeneralProjectSettings]` of the configuration
+    file `DefaultGame.ini` located in the folder `$ROOT_PATH/Config` of
+    the Unreal Engine project.
+
+    https://docs.unrealengine.com/5.0/en-US/configuration-files-in-unreal-engine/
+
+
+    @param path: The absolute path to the root folder of an Unreal Engine
+        project.
+
+    @param version: The version to write inn the Unreal Engine project
+        configuration file.
+    """
+    if not path.exists():
+        raise ValueError(f"The path {path} doesn't exist")
+
+    config_file_path = Path().joinpath(path.expanduser(), 'Config', 'DefaultGame.ini')
+
+    with open(config_file_path, 'rt') as fd:
+        lines = fd.readlines()
+
+    is_project_version_defined = False
+
+    for i in range(len(lines)):
+        regex_match = REGEX_PROPERTY.match(lines[i].strip())
+        if regex_match:
+            lines[i] = f'{UNREAL_ENGINE_CONFIG_PROPERTY_PROJECT_VERSION}={version}'
+            is_project_version_defined = True
+            break
+
+    if not is_project_version_defined:
+        raise ValueError(f"The Unreal Engine project has no version defined in the configuration file {config_file_path}")
+
+    with open(config_file_path, 'wt') as fd:
+        fd.writelines(lines)
